@@ -69,7 +69,10 @@ describe 'keystone::bootstrap' do
         :roles  => ['admin'],
       )}
 
-      it { is_expected.to contain_keystone_service('keystone::identity').with_ensure('present') }
+      it { is_expected.to contain_keystone_service('keystone::identity').with(
+        :ensure      => 'present',
+        :description => 'OpenStack Identity Service'
+      ) }
 
       it { is_expected.to contain_keystone_endpoint('RegionOne/keystone::identity').with(
         :ensure       => 'present',
@@ -113,6 +116,7 @@ describe 'keystone::bootstrap' do
           :service_project_name => 'serviceproj',
           :role_name            => 'adminrole',
           :service_name         => 'servicename',
+          :service_description  => 'Alternative OpenStack Identity Service',
           :admin_url            => 'http://admin:1234',
           :public_url           => 'http://public:4321',
           :internal_url         => 'http://internal:1342',
@@ -181,7 +185,10 @@ describe 'keystone::bootstrap' do
         :roles  => ['adminrole'],
       )}
 
-      it { is_expected.to contain_keystone_service('servicename::identity').with_ensure('present') }
+      it { is_expected.to contain_keystone_service('servicename::identity').with(
+        :ensure      => 'present',
+        :description => 'Alternative OpenStack Identity Service'
+      ) }
 
       it { is_expected.to contain_keystone_endpoint('RegionTwo/servicename::identity').with(
         :ensure       => 'present',
@@ -227,13 +234,13 @@ describe 'keystone::bootstrap' do
 
       it { is_expected.to_not contain_exec('keystone bootstrap') }
 
-      it { is_expected.to_not contain_keystone_role('admin') }
-      it { is_expected.to_not contain_keystone_user('admin') }
-      it { is_expected.to_not contain_keystone_tenant('services') }
-      it { is_expected.to_not contain_keystone_tenant('admin') }
-      it { is_expected.to_not contain_keystone_user_role('admin@admin') }
-      it { is_expected.to_not contain_keystone_service('keystone::identity') }
-      it { is_expected.to_not contain_keystone_endpoint('RegionOne/keystone::identity') }
+      it { is_expected.to contain_keystone_role('admin') }
+      it { is_expected.to contain_keystone_user('admin') }
+      it { is_expected.to contain_keystone_tenant('services') }
+      it { is_expected.to contain_keystone_tenant('admin') }
+      it { is_expected.to contain_keystone_user_role('admin@admin') }
+      it { is_expected.to contain_keystone_service('keystone::identity') }
+      it { is_expected.to contain_keystone_endpoint('RegionOne/keystone::identity') }
 
       it { is_expected.to contain_file('/etc/openstack').with(
         :ensure  => 'directory',
@@ -276,6 +283,28 @@ describe 'keystone::bootstrap' do
       it { is_expected.to contain_exec('keystone bootstrap').with_user('some') }
     end
 
+    context 'with bootstrap enabled and manage_resource to false' do
+      let :params do
+        {
+          :bootstrap        => false,
+          :manage_resources => false,
+          :password         => 'secret'
+        }
+      end
+
+      it { is_expected.to contain_class('keystone::deps') }
+
+      it { is_expected.to_not contain_exec('keystone bootstrap') }
+
+      it { is_expected.to_not contain_keystone_role('admin') }
+      it { is_expected.to_not contain_keystone_user('admin') }
+      it { is_expected.to_not contain_keystone_tenant('services') }
+      it { is_expected.to_not contain_keystone_tenant('admin') }
+      it { is_expected.to_not contain_keystone_user_role('admin@admin') }
+      it { is_expected.to_not contain_keystone_service('keystone::identity') }
+      it { is_expected.to_not contain_keystone_endpoint('RegionOne/keystone::identity') }
+    end
+
     context 'when setting interface to internal' do
       let :params do
         {
