@@ -51,11 +51,14 @@ describe 'keystone::federation::mellon' do
         is_expected.to contain_keystone_config('mapped/remote_id_attribute').with_ensure('absent')
       end
 
-      it { is_expected.to contain_concat__fragment('configure_mellon_keystone').with({
+      it { is_expected.to contain_apache__vhost__fragment('configure_mellon_keystone').with({
+        :vhost    => 'keystone_wsgi',
         # This need to change if priority is changed in keystone::wsgi::apache
-        :target => "10-keystone_wsgi.conf",
-        :order  => params[:template_order],
+        :priority => 10,
+        :order    => params[:template_order],
       })}
+
+      it { is_expected.to contain_concat('10-keystone_wsgi.conf').with_show_diff(false) }
     end
 
     context 'with websso enabled' do
@@ -73,10 +76,14 @@ describe 'keystone::federation::mellon' do
         is_expected.to contain_keystone_config('mapped/remote_id_attribute').with_value('MELLON_IDP')
       end
 
-      it { is_expected.to contain_concat__fragment('configure_mellon_keystone').with({
-        :target => "10-keystone_wsgi.conf",
-        :order  => params[:template_order],
+      it { is_expected.to contain_apache__vhost__fragment('configure_mellon_keystone').with({
+        :vhost    => 'keystone_wsgi',
+        # This need to change if priority is changed in keystone::wsgi::apache
+        :priority => 10,
+        :order    => params[:template_order],
       })}
+
+      it { is_expected.to contain_concat('10-keystone_wsgi.conf').with_show_diff(false) }
     end
   end
 
