@@ -32,12 +32,14 @@ describe 'keystone' do
       it 'should set the default values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => false })
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('token/provider').with_value('fernet')
         is_expected.to contain_keystone_config('token/expiration').with_value(3600)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('identity/max_password_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('revoke/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('policy/driver').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
+        is_expected.to contain_keystone_config('token/revoke_by_id').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
@@ -46,8 +48,8 @@ describe 'keystone' do
 
         is_expected.to contain_keystone_config('catalog/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('catalog/template_file').with_value('/etc/keystone/default_catalog.templates')
-        is_expected.to contain_keystone_config('token/provider').with_value('fernet')
         is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('DEFAULT/list_limit').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('DEFAULT/notification_opt_out').with_value('<SERVICE DEFAULT>')
 
@@ -62,27 +64,30 @@ describe 'keystone' do
           :transport_url => '<SERVICE DEFAULT>',
           :driver        => '<SERVICE DEFAULT>',
           :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
 
         is_expected.to contain_oslo__messaging__rabbit('keystone_config').with(
-          :kombu_ssl_version                  => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile                  => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile                 => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs                 => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay              => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy            => '<SERVICE DEFAULT>',
-          :kombu_compression                  => '<SERVICE DEFAULT>',
-          :rabbit_use_ssl                     => '<SERVICE DEFAULT>',
-          :rabbit_ha_queues                   => '<SERVICE DEFAULT>',
-          :heartbeat_timeout_threshold        => '<SERVICE DEFAULT>',
-          :heartbeat_rate                     => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread               => '<SERVICE DEFAULT>',
-          :amqp_durable_queues                => '<SERVICE DEFAULT>',
-          :rabbit_quorum_queue                => '<SERVICE DEFAULT>',
-          :rabbit_transient_quorum_queue      => '<SERVICE DEFAULT>',
-          :rabbit_quorum_delivery_limit       => '<SERVICE DEFAULT>',
-          :rabbit_quorum_max_memory_length    => '<SERVICE DEFAULT>',
-          :rabbit_quorum_max_memory_bytes     => '<SERVICE DEFAULT>',
+          :kombu_ssl_version               => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :kombu_compression               => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+          :heartbeat_rate                  => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
+          :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
 
         is_expected.to contain_keystone_config('identity/domain_specific_drivers_enabled').with_ensure('absent')
@@ -103,6 +108,21 @@ describe 'keystone' do
 
       it { is_expected.to_not contain_file('/etc/keystone/domains') }
 
+      it { is_expected.to contain_file('/etc/keystone/fernet-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        'mode'  => '0600',
+      ) }
+
+      it { is_expected.to contain_exec('keystone-manage fernet_setup').with(
+        :command => 'keystone-manage fernet_setup --keystone-user keystone --keystone-group keystone',
+        :user    => 'keystone',
+        :creates => '/etc/keystone/fernet-keys/0',
+        :require => 'File[/etc/keystone/fernet-keys]',
+      ) }
+      it { is_expected.to contain_keystone_config('fernet_tokens/key_repository').with_value('/etc/keystone/fernet-keys') }
+
       it { is_expected.to contain_file('/etc/keystone/credential-keys').with(
         :ensure => 'directory',
         :owner  => 'keystone',
@@ -124,9 +144,11 @@ describe 'keystone' do
         {
           :purge_config                 => true,
           :public_endpoint              => 'http://127.0.0.1:5000',
+          :token_provider               => 'uuid',
           :token_expiration             => 7200,
           :password_hash_algorithm      => 'bcrypt',
           :password_hash_rounds         => 12,
+          :max_password_length          => 54,
           :revoke_driver                => 'sql',
           :policy_driver                => 'sql',
           :revoke_by_id                 => true,
@@ -134,8 +156,8 @@ describe 'keystone' do
           :max_request_body_size        => 114688,
           :catalog_driver               => 'templated',
           :catalog_template_file        => '/some/template_file',
-          :token_provider               => 'uuid',
           :max_token_size               => 255,
+          :list_limit                   => 10000,
           :notification_format          => 'basic',
           :notification_opt_out         => [
             'identity.authenticate.success',
@@ -148,9 +170,11 @@ describe 'keystone' do
       it 'should set the overridden values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => true })
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
+        is_expected.to contain_keystone_config('token/provider').with_value('uuid')
         is_expected.to contain_keystone_config('token/expiration').with_value(7200)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('bcrypt')
         is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value(12)
+        is_expected.to contain_keystone_config('identity/max_password_length').with_value(54)
         is_expected.to contain_keystone_config('revoke/driver').with_value('sql')
         is_expected.to contain_keystone_config('policy/driver').with_value('sql')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
@@ -162,8 +186,8 @@ describe 'keystone' do
 
         is_expected.to contain_keystone_config('catalog/driver').with_value('templated')
         is_expected.to contain_keystone_config('catalog/template_file').with_value('/some/template_file')
-        is_expected.to contain_keystone_config('token/provider').with_value('uuid')
         is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value(255)
+        is_expected.to contain_keystone_config('DEFAULT/list_limit').with_value(10000)
         is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('basic')
         is_expected.to contain_keystone_config('DEFAULT/notification_opt_out').with_value([
           'identity.authenticate.success',
@@ -217,6 +241,15 @@ describe 'keystone' do
       it { is_expected.to_not contain_service('keystone') }
     end
 
+    context 'with disabled package managing' do
+      let :params do
+        { :manage_package => false }
+      end
+
+      it { is_expected.to_not contain_package('keystone') }
+      it { is_expected.to_not contain_class('openstacklib::openstackclient') }
+    end
+
     context 'when sync_db is set to false' do
       let :params do
         {
@@ -268,6 +301,7 @@ describe 'keystone' do
           :notification_transport_url => 'rabbit://user:pass@host:1234/virt',
           :notification_driver        => ['keystone.openstack.common.notifier.rpc_notifier'],
           :notification_topics        => ['notifications'],
+          :notification_retry         => 10,
           :control_exchange           => 'keystone',
           :rpc_response_timeout       => 120,
           :executor_thread_pool_size  => 64,
@@ -286,6 +320,7 @@ describe 'keystone' do
           :transport_url => 'rabbit://user:pass@host:1234/virt',
           :driver        => ['keystone.openstack.common.notifier.rpc_notifier'],
           :topics        => ['notifications'],
+          :retry         => 10,
         )
       }
     end
@@ -384,16 +419,16 @@ describe 'keystone' do
       )}
     end
 
-    context 'when disabling credential_setup' do
+    context 'when disabling fernet_setup' do
       let :params do
         {
-          'enable_credential_setup'   => false,
-          'credential_key_repository' => '/etc/keystone/credential-keys',
+          'enable_fernet_setup' => false,
         }
       end
 
-      it { is_expected.to_not contain_file(params['credential_key_repository']) }
-      it { is_expected.to_not contain_exec('keystone-manage credential_setup') }
+      it { is_expected.to_not contain_file('/etc/keystone/fernet-keys') }
+      it { is_expected.to_not contain_exec('keystone-manage fernet_setup') }
+      it { is_expected.to contain_keystone_config('fernet_tokens/key_repository').with_value('/etc/keystone/fernet-keys') }
     end
 
     context 'when enabling fernet_setup' do
@@ -401,12 +436,10 @@ describe 'keystone' do
         {
           'enable_fernet_setup'    => true,
           'fernet_max_active_keys' => 5,
-          'revoke_by_id'           => false,
-          'fernet_key_repository'  => '/etc/keystone/fernet-keys',
         }
       end
 
-      it { is_expected.to contain_file(params['fernet_key_repository']).with(
+      it { is_expected.to contain_file('/etc/keystone/fernet-keys').with(
         :ensure => 'directory',
         :owner  => 'keystone',
         :group  => 'keystone',
@@ -420,7 +453,6 @@ describe 'keystone' do
         :require => 'File[/etc/keystone/fernet-keys]',
       ) }
       it { is_expected.to contain_keystone_config('fernet_tokens/max_active_keys').with_value(5)}
-      it { is_expected.to contain_keystone_config('token/revoke_by_id').with_value(false)}
     end
 
     context 'when overriding the fernet key directory' do
@@ -431,18 +463,25 @@ describe 'keystone' do
         }
       end
 
+      it { is_expected.to contain_file('/var/lib/fernet-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        :mode   => '0600',
+      ) }
+
       it { is_expected.to contain_exec('keystone-manage fernet_setup').with(
         :creates => '/var/lib/fernet-keys/0'
       ) }
+      it { is_expected.to contain_keystone_config('fernet_tokens/key_repository').with_value('/var/lib/fernet-keys') }
     end
 
     context 'when overriding the keystone group and user' do
       let :params do
         {
-          'enable_fernet_setup'   => true,
-          'fernet_key_repository' => '/etc/keystone/fernet-keys',
-          'keystone_user'         => 'test_user',
-          'keystone_group'        => 'test_group',
+          'enable_fernet_setup' => true,
+          'keystone_user'       => 'test_user',
+          'keystone_group'      => 'test_group',
         }
       end
 
